@@ -1,8 +1,10 @@
+import asyncio
+
 from jupyter_core.paths import jupyter_data_dir
 from jupyter_server.extension.application import ExtensionApp
 from jupyter_server.traittypes import TypeFromClasses
 from jupyter_server.transutils import _i18n
-from traitlets import Bool, Unicode, default
+from traitlets import Bool, Integer, Unicode, default
 
 from jupyter_scheduler.orm import create_tables
 from jupyter_scheduler.scheduler import Scheduler
@@ -18,6 +20,7 @@ from .handlers import (
     JobsCountHandler,
     RuntimeEnvironmentsHandler,
 )
+from .task_runner import TaskRunner
 
 JOB_DEFINITION_ID_REGEX = r"(?P<job_definition_id>\w+-\w+-\w+-\w+-\w+)"
 JOB_ID_REGEX = r"(?P<job_id>\w+-\w+-\w+-\w+-\w+)"
@@ -65,17 +68,39 @@ class SchedulerApp(ExtensionApp):
         help=_i18n("The scheduler class to use."),
     )
 
+    task_runner_run_interval = Integer(
+        default_value=10,
+        config=True,
+        help=_i18n("The interval in seconds that the task runner polls for scheduled jobs to run."),
+    )
+
+    task_runner_class = TypeFromClasses(
+        default_value=TaskRunner,
+        klasses=["jupyter_scheduler.task_runner.BaseTaskRunner"],
+        help=_i18n(
+            "The class that handles the job creation of scheduled jobs from job definitions."
+        ),
+    )
+
     def initialize_settings(self):
         super().initialize_settings()
 
         create_tables(self.db_url, self.drop_tables)
 
-        self.settings.update(
-            execution_config=ExecutionConfig(
-                db_url=self.db_url,
-                execution_manager_class=self.execution_manager_class,
-                environments_manager_class=self.environment_manager_class,
-                scheduler_class=self.scheduler_class,
-                root_dir=self.settings.get("server_root_dir", None),
-            )
+        execution_config = ExecutionConfig(
+            db_url=self.db_url,
+            execution_manager_class=self.execution_manager_class,
+            environments_manager_class=self.environment_manager_class,
+            root_dir=self.settings.get("server_root_dir", None),
+            task_runner_run_interval=self.task_runner_run_interval,
         )
+
+        scheduler = self.scheduler_class(
+            config=execution_config, task_runner_class=self.task_runner_class
+        )
+
+        self.settings.update(execution_config=execution_config, scheduler=scheduler)
+
+        if self.task_runner_run_interval >= 1 and scheduler.task_runner:
+            loop = asyncio.get_event_loop()
+            loop.create_task(scheduler.task_runner.start())
