@@ -144,10 +144,7 @@ class CountJobsQuery(BaseModel):
 
 
 class UpdateJob(BaseModel):
-    job_id: str
-    end_time: Optional[int] = None
     status: Optional[Status] = None
-    status_message: Optional[str] = None
     name: Optional[str] = None
     compute_type: Optional[str] = None
 
@@ -182,7 +179,6 @@ class DescribeJobDefinition(CreateJobDefinition):
 
 
 class UpdateJobDefinition(BaseModel):
-    job_definition_id: str
     input_uri: Optional[str]
     output_prefix: Optional[str]
     runtime_environment_name: Optional[str]
@@ -192,9 +188,11 @@ class UpdateJobDefinition(BaseModel):
     tags: Optional[Tags] = None
     name: Optional[str] = None
     url: Optional[str] = None
-    timezone: Optional[str] = None  # Should be a timezone e.g., US/Eastern, Asia/Kolkata
+    schedule: Optional[str] = None
+    timezone: Optional[str] = None
     output_filename_template: Optional[str] = OUTPUT_FILENAME_TEMPLATE
-    active: bool
+    active: Optional[bool] = None
+    compute_type: Optional[str] = None
 
 
 class ListJobDefinitionsQuery(BaseModel):
