@@ -205,7 +205,9 @@ async function activatePlugin(
         jobName: fileName,
         outputPath: '',
         environment: '',
-        createType: 'Job'
+        createType: 'Job',
+        scheduleInterval: 'weekday',
+        timezone: Intl.DateTimeFormat().resolvedOptions().timeZone
       };
 
       model.createJobModel = newModel;
