@@ -15,6 +15,7 @@ import Button from '@mui/material/Button';
 import Link from '@mui/material/Link';
 import Stack from '@mui/material/Stack';
 import {
+  Alert,
   Card,
   CardContent,
   FormLabel,
@@ -23,7 +24,12 @@ import {
 } from '@mui/material';
 
 export const TextFieldStyled = (props: TextFieldProps): JSX.Element => (
-  <TextField {...props} variant="outlined" InputProps={{ readOnly: true }} />
+  <TextField
+    {...props}
+    variant="outlined"
+    InputProps={{ readOnly: true }}
+    FormHelperTextProps={{ sx: { maxWidth: 'fit-content' } }}
+  />
 );
 export interface IJobDetailProps {
   app: JupyterFrontEnd;
@@ -60,8 +66,12 @@ export function JobDetail(props: IJobDetailProps): JSX.Element {
       inputFile: props.model.inputFile,
       outputPath: props.model.outputPrefix ?? '',
       environment: props.model.environment,
+      runtimeEnvironmentParameters: props.model.runtimeEnvironmentParameters,
       parameters: props.model.parameters,
-      createType: 'Job'
+      outputFormats: props.model.outputFormats,
+      createType: 'Job',
+      scheduleInterval: 'weekday',
+      timezone: Intl.DateTimeFormat().resolvedOptions().timeZone
     };
 
     props.setCreateJobModel(initialState);
@@ -261,6 +271,9 @@ export function JobDetail(props: IJobDetailProps): JSX.Element {
   return (
     <>
       {ButtonBar}
+      {props.model.statusMessage && (
+        <Alert severity="error">{props.model.statusMessage}</Alert>
+      )}
       {CoreOptions}
       {Parameters}
       {AdvancedOptions}
