@@ -169,8 +169,18 @@ function ListJobDefinitionsTable(props: ListJobDefinitionsTableProps) {
   const trans = useTranslator('jupyterlab');
   const [jobDefsQuery, setJobDefsQuery] =
     useState<Scheduler.IListJobDefinitionsQuery>({});
+  const [deletedRows, setDeletedRows] = useState<
+    Set<Scheduler.IDescribeJobDefinition['job_definition_id']>
+  >(new Set());
   const api = useMemo(() => new SchedulerService({}), []);
 
+  const deleteRow = useCallback(
+    (id: Scheduler.IDescribeJobDefinition['job_definition_id']) => {
+      setDeletedRows(deletedRows => new Set([...deletedRows, id]));
+    },
+    []
+  );
+
   const columns: AdvancedTableColumn[] = [
     {
       sortField: 'name',
@@ -183,6 +193,18 @@ function ListJobDefinitionsTable(props: ListJobDefinitionsTableProps) {
     {
       sortField: 'create_time',
       name: trans.__('Created at')
+    },
+    {
+      sortField: null,
+      name: trans.__('Schedule')
+    },
+    {
+      sortField: null,
+      name: trans.__('Status')
+    },
+    {
+      sortField: null,
+      name: trans.__('Actions')
     }
   ];
 
@@ -199,7 +221,18 @@ function ListJobDefinitionsTable(props: ListJobDefinitionsTableProps) {
   );
 
   const renderRow = (jobDef: Scheduler.IDescribeJobDefinition) =>
-    buildJobDefinitionRow(jobDef, props.app, props.showJobDefinitionDetail);
+    buildJobDefinitionRow(
+      jobDef,
+      props.app,
+      props.showJobDefinitionDetail,
+      deleteRow,
+      () => setJobDefsQuery({}),
+      trans,
+      new SchedulerService({})
+    );
+
+  const rowFilter = (jobDef: Scheduler.IDescribeJobDefinition) =>
+    !deletedRows.has(jobDef.job_definition_id);
 
   const emptyRowMessage = useMemo(
     () => trans.__('There are no notebook job definitions.'),
@@ -219,6 +252,7 @@ function ListJobDefinitionsTable(props: ListJobDefinitionsTableProps) {
         renderRow={renderRow}
         columns={columns}
         emptyRowMessage={emptyRowMessage}
+        rowFilter={rowFilter}
       />
     </>
   );
